@@ -400,13 +400,13 @@ IOUSBInterfaceUserClient::start( IOService * provider )
 
     if (!fOwner)
     {
-        USBError(1, "%s[%p]::start - provider is NULL!", getName(), this);
-        goto ErrorExit;
+ 	USBError(1, "%s[%p]::start - provider is NULL!", getName(), this);
+	goto ErrorExit;
     }
     
     if(!super::start(provider))
     {
-        USBError(1, "%s[%p]::start - super::start returned false!", getName(), this);
+ 	USBError(1, "%s[%p]::start - super::start returned false!", getName(), this);
         goto ErrorExit;
     }
 
@@ -414,34 +414,29 @@ IOUSBInterfaceUserClient::start( IOService * provider )
 
     if(!fGate)
     {
-        USBError(1, "%s[%p]::start - unable to create command gate", getName(), this);
-        goto ErrorExit;
+	USBError(1, "%s[%p]::start - unable to create command gate", getName(), this);
+	goto ErrorExit;
     }
 
     fWorkLoop = getWorkLoop();
     if (!fWorkLoop)
     {
-        USBError(1, "%s[%p]::start - unable to find my workloop", getName(), this);
-        goto ErrorExit;
+	USBError(1, "%s[%p]::start - unable to find my workloop", getName(), this);
+	goto ErrorExit;
     }
     fWorkLoop->retain();
     
     if (fWorkLoop->addEventSource(fGate) != kIOReturnSuccess)
     {
-        USBError(1, "%s[%p]::start - unable to add gate to work loop", getName(), this);
-        goto ErrorExit;
+	USBError(1, "%s[%p]::start - unable to add gate to work loop", getName(), this);
+	goto ErrorExit;
     }
 
     fFreeUSBLowLatencyCommandPool = IOCommandPool::withWorkLoop(fWorkLoop);
     if (!fFreeUSBLowLatencyCommandPool)
     {
         USBError(1,"%s[%p]::start - unable to create free command pool", getName(), this);
-        
-        // Remove the event source we added above
-        //
-        fWorkLoop->removeEventSource(fGate);
-        
-        goto ErrorExit;
+	goto ErrorExit;
     }
 
     DecrementOutstandingIO();
@@ -496,7 +491,7 @@ IOUSBInterfaceUserClient::close()
 {
     IOReturn 	ret = kIOReturnSuccess;
     
-    USBLog(7, "+%s[%p]::close", getName(), this);
+    USBLog(5, "+%s[%p]::close", getName(), this);
     IncrementOutstandingIO();
     
     if (fOwner && !isInactive())
@@ -520,7 +515,7 @@ IOUSBInterfaceUserClient::close()
 	ret = kIOReturnNotAttached;
  
     DecrementOutstandingIO();
-    USBLog(7, "-%s[%p]::close - returning %x", getName(), this, ret);
+    USBLog(5, "-%s[%p]::close - returning %x", getName(), this, ret);
     return ret;
 }
 
@@ -533,7 +528,10 @@ IOUSBInterfaceUserClient::close()
 IOReturn 
 IOUSBInterfaceUserClient::clientClose( void )
 {
-    USBLog(7, "+%s[%p]::clientClose(%p)", getName(), this, fUserClientBufferInfoListHead);
+    LowLatencyUserClientBufferInfo *	kernelDataBuffer;
+    LowLatencyUserClientBufferInfo *	nextBuffer;
+
+    USBLog(5, "+%s[%p]::clientClose(%p)", getName(), this, fUserClientBufferInfoListHead);
 
     // Sleep for 1 ms to allow other threads that are pending to run
     //
@@ -543,14 +541,49 @@ IOUSBInterfaceUserClient::clientClose( void )
     //
     if (fUserClientBufferInfoListHead != NULL)
     {
-        ReleasePreparedDescriptors();
+        nextBuffer = fUserClientBufferInfoListHead;
+        kernelDataBuffer = fUserClientBufferInfoListHead;
+        
+        // Traverse the list and release memory
+        //
+        while ( nextBuffer != NULL )
+        {
+            nextBuffer = kernelDataBuffer->nextBuffer;
+            
+            // Now, need to complete/release/free the objects we allocated in our prepare
+            //
+            if ( kernelDataBuffer->frameListMap )
+                kernelDataBuffer->frameListMap->release();
+                
+            if ( kernelDataBuffer->frameListDescriptor )
+            {
+                kernelDataBuffer->frameListDescriptor->release();
+            }
+            
+            if ( kernelDataBuffer->bufferDescriptor )
+            {
+                // We call prepare on the bufferDescriptor, so we need to call complete on it 
+                //
+                kernelDataBuffer->bufferDescriptor->complete();
+                kernelDataBuffer->bufferDescriptor->release();
+            }
+            
+            // Finally, deallocate our kernelDataBuffer
+            //
+            IOFree(kernelDataBuffer, sizeof(LowLatencyUserClientBufferInfo));
+            
+            kernelDataBuffer = nextBuffer;
+        }
+        
+        fUserClientBufferInfoListHead = NULL;
     }
 
+
     fTask = NULL;
     
     terminate();
 
-    USBLog(7, "-%s[%p]::clientClose(%p)", getName(), this, fUserClientBufferInfoListHead);
+    USBLog(5, "-%s[%p]::clientClose(%p)", getName(), this, fUserClientBufferInfoListHead);
 
     return kIOReturnSuccess;			// DONT call super::clientClose, which just returns notSupported
 }
@@ -561,12 +594,12 @@ IOUSBInterfaceUserClient::clientDied( void )
 {
     IOReturn ret;
 
-    USBLog(5, "+%s[%p]::clientDied()", getName(), this);
+    USBLog(3, "+%s[%p]::clientDied()", getName(), this);
 
     fDead = true;				// don't send any mach messages in this case
     ret = super::clientDied();
 
-    USBLog(5, "-%s[%p]::clientDied()", getName(), this);
+    USBLog(3, "-%s[%p]::clientDied()", getName(), this);
 
     return ret;
 }
@@ -1471,11 +1504,11 @@ IOUSBInterfaceUserClient::LowLatencyPrepareBuffer(LowLatencyUserBufferInfo *buff
         kernelDataBuffer = ( LowLatencyUserClientBufferInfo *) IOMalloc( sizeof(LowLatencyUserClientBufferInfo) );
         if (kernelDataBuffer == NULL )
         {
-            USBLog(1,"%s[%p]::LowLatencyPrepareBuffer  Could not malloc buffer info (size = %d)!", getName(), this, sizeof(LowLatencyUserClientBufferInfo) );
+            USBLog(3,"%s[%p]::LowLatencyPrepareBuffer  Could not malloc buffer (size = %d)!", getName(), this, sizeof(LowLatencyUserClientBufferInfo) );
             return kIOReturnNoMemory;
         }
         
-        bzero(kernelDataBuffer, sizeof(LowLatencyUserClientBufferInfo));
+	bzero(kernelDataBuffer, sizeof(LowLatencyUserClientBufferInfo));
         
         // Cool, we have a good buffer, add it to our list
         //
@@ -1496,7 +1529,6 @@ IOUSBInterfaceUserClient::LowLatencyPrepareBuffer(LowLatencyUserBufferInfo *buff
             aDescriptor = IOMemoryDescriptor::withAddress((vm_address_t)bufferData->bufferAddress, bufferData->bufferSize, direction, fTask);
             if(!aDescriptor) 
             {
-                USBLog(1,"%s[%p]::LowLatencyPrepareBuffer  Could not create a data buffer memory descriptor (addr: %p, size %d)!", getName(), this, bufferData->bufferAddress, bufferData->bufferSize );
                 ret = kIOReturnNoMemory;
                 goto ErrorExit;
             }
@@ -1504,7 +1536,6 @@ IOUSBInterfaceUserClient::LowLatencyPrepareBuffer(LowLatencyUserBufferInfo *buff
             ret = aDescriptor->prepare();
             if (ret != kIOReturnSuccess)
             {
-                USBLog(1,"%s[%p]::LowLatencyPrepareBuffer  Could not prepare the data buffer memory descriptor!", getName(), this );
                 goto ErrorExit;
             }
 
@@ -1522,33 +1553,28 @@ IOUSBInterfaceUserClient::LowLatencyPrepareBuffer(LowLatencyUserBufferInfo *buff
         {
             // We have a frame list that we need to map to the kernel's memory space
             //
-            // Create a memory descriptor for our frame list and prepare it (pages it in if necesary and prepares it). 
+            // Create a buffer memory descriptor for our frame list and prepare it (pages it in if necesary and prepares it).  A buffer memory
+            // descriptor allows us to get the pointer to the data
             //
             aDescriptor = IOMemoryDescriptor::withAddress((vm_address_t)bufferData->bufferAddress, bufferData->bufferSize, kIODirectionOutIn, fTask);
             if(!aDescriptor) 
             {
-                USBLog(1,"%s[%p]::LowLatencyPrepareBuffer  Could not create a frame list memory descriptor (addr: %p, size %d)!", getName(), this, bufferData->bufferAddress, bufferData->bufferSize );
-                ret = kIOReturnNoMemory;
-                goto ErrorExit;
-            }
-            
-            ret = aDescriptor->prepare();
-            if (ret != kIOReturnSuccess)
-            {
-                USBLog(1,"%s[%p]::LowLatencyPrepareBuffer  Could not prepare the frame list memory descriptor!", getName(), this );
                 ret = kIOReturnNoMemory;
                 goto ErrorExit;
             }
             
+            //  Do we need to prepare this descriptor?
+            //
+            // ret = aDescriptor->prepare();
+            //if (ret != kIOReturnSuccess)
+            //    break;
 
             // Map it into the kernel
             //
             frameListMap = aDescriptor->map();
-            if (!frameListMap) 
+            if(!frameListMap) 
             {
-                USBLog(1,"%s[%p]::LowLatencyPrepareBuffer  Could not prepare the frame list memory descriptor!", getName(), this );
                 ret = kIOReturnNoMemory;
-                aDescriptor->complete();
                 goto ErrorExit;
             }
 
@@ -1574,7 +1600,7 @@ IOUSBInterfaceUserClient::LowLatencyPrepareBuffer(LowLatencyUserBufferInfo *buff
 ErrorExit:
 
     if (ret)
-        USBLog(3, "%s[%p]::LowLatencyPrepareBuffer - returning err %x", getName(), this, ret);
+	USBLog(3, "%s[%p]::LowLatencyPrepareBuffer - returning err %x", getName(), this, ret);
 
     DecrementOutstandingIO();
     
@@ -1601,7 +1627,6 @@ IOUSBInterfaceUserClient::LowLatencyReleaseBuffer(LowLatencyUserBufferInfo *data
         kernelDataBuffer = FindBufferCookieInList( dataBuffer->cookie );
         if ( kernelDataBuffer == NULL )
         {
-            USBLog(3, "+%s[%p]::LowLatencyReleaseBuffer cookie: %ld, could not find buffer in list", getName(), this, dataBuffer->cookie);
             ret = kIOReturnBadArgument;
             goto ErrorExit;
         }
@@ -1611,7 +1636,6 @@ IOUSBInterfaceUserClient::LowLatencyReleaseBuffer(LowLatencyUserBufferInfo *data
         found = RemoveDataBufferFromList( kernelDataBuffer );
         if ( !found )
         {
-            USBLog(3, "+%s[%p]::LowLatencyReleaseBuffer cookie: %ld, could not remove buffer (%p) from list", getName(), this, dataBuffer->cookie);
             ret = kIOReturnBadArgument;
             goto ErrorExit;
         }
@@ -1622,11 +1646,8 @@ IOUSBInterfaceUserClient::LowLatencyReleaseBuffer(LowLatencyUserBufferInfo *data
             kernelDataBuffer->frameListMap->release();
             
         if ( kernelDataBuffer->frameListDescriptor )
-        {
-            kernelDataBuffer->frameListDescriptor->complete();
             kernelDataBuffer->frameListDescriptor->release();
-        }
-        
+
         if ( kernelDataBuffer->bufferDescriptor )
         {
             kernelDataBuffer->bufferDescriptor->complete();
@@ -1645,7 +1666,7 @@ IOUSBInterfaceUserClient::LowLatencyReleaseBuffer(LowLatencyUserBufferInfo *data
 ErrorExit:
 
     if (ret)
-        USBLog(3, "%s[%p]::LowLatencyReleaseBuffer - returning err %x", getName(), this, ret);
+	USBLog(3, "%s[%p]::LowLatencyReleaseBuffer - returning err %x", getName(), this, ret);
 
     DecrementOutstandingIO();
     return ret;
@@ -2348,11 +2369,20 @@ IOUSBInterfaceUserClient::stop(IOService * provider)
     
     USBLog(7, "+%s[%p]::stop(%p)", getName(), this, provider);
 
-    // If we have any kernelDataBuffer pointers, then release them now
-    //
-    if (fUserClientBufferInfoListHead != NULL)
+    if (fGate)
     {
-        ReleasePreparedDescriptors();
+	if (fWorkLoop)
+	{
+	    fWorkLoop->removeEventSource(fGate);
+            fWorkLoop->release();
+            fWorkLoop = NULL;
+	}
+	else
+	{
+	    USBError(1, "%s[%p]::free - have gate, but no valid workloop (%p)!", getName(), this, fWorkLoop);
+	}
+	fGate->release();
+	fGate = NULL;
     }
 
     super::stop(provider);
@@ -2364,33 +2394,23 @@ IOUSBInterfaceUserClient::stop(IOService * provider)
 void 
 IOUSBInterfaceUserClient::free()
 {
-    IOReturn ret;
-
-    // USBLog(7, "+%s[%p]::free", getName(), this);
     
-    if ( fFreeUSBLowLatencyCommandPool )
-    {
-       //  USBLog(5, "+%s[%p]::free releasing fFreeUSBLowLatencyCommandPool", getName(), this);
-        fFreeUSBLowLatencyCommandPool->release();
-    }
-
     if (fGate)
     {
-        if (fWorkLoop)
-        {
-            ret = fWorkLoop->removeEventSource(fGate);
-            // USBLog(5, "+%s[%p]::free releasing fWorkLoop", getName(), this);
+	if (fWorkLoop)
+	{
+	    fWorkLoop->removeEventSource(fGate);
             fWorkLoop->release();
             fWorkLoop = NULL;
-        }
-        else
-        {
-            USBError(1, "%s[%p]::free - have gate, but no valid workloop (%p)!", getName(), this, fWorkLoop);
-        }
-        fGate->release();
-        fGate = NULL;
+	}
+	else
+	{
+	    USBError(1, "%s[%p]::free - have gate, but no valid workloop (%p)!", getName(), this, fWorkLoop);
+	}
+	fGate->release();
+	fGate = NULL;
     }
-        
+    
     super::free();
 }
 
@@ -2545,57 +2565,6 @@ IOUSBInterfaceUserClient::IncreaseCommandPool(void)
 
 }
 
-void
-IOUSBInterfaceUserClient::ReleasePreparedDescriptors(void)
-{
-    LowLatencyUserClientBufferInfo *	kernelDataBuffer;
-    LowLatencyUserClientBufferInfo *	nextBuffer;
-
-    // If we have any kernelDataBuffer pointers, then release them now
-    //
-    if (fUserClientBufferInfoListHead != NULL)
-    {
-        USBLog(5, "+%s[%p]::stop: fUserClientBufferInfoListHead NOT NULL (%p) ", getName(), this, fUserClientBufferInfoListHead);
-    
-        nextBuffer = fUserClientBufferInfoListHead;
-        kernelDataBuffer = fUserClientBufferInfoListHead;
-        
-        // Traverse the list and release memory
-        //
-        while ( nextBuffer != NULL )
-        {
-            nextBuffer = kernelDataBuffer->nextBuffer;
-            
-            // Now, need to complete/release/free the objects we allocated in our prepare
-            //
-            if ( kernelDataBuffer->frameListMap )
-                kernelDataBuffer->frameListMap->release();
-                
-            if ( kernelDataBuffer->frameListDescriptor )
-            {
-                kernelDataBuffer->frameListDescriptor->complete();
-                kernelDataBuffer->frameListDescriptor->release();
-            }
-
-            if ( kernelDataBuffer->bufferDescriptor )
-            {
-                // We call prepare on the bufferDescriptor, so we need to call complete on it 
-                //
-                kernelDataBuffer->bufferDescriptor->complete();
-                kernelDataBuffer->bufferDescriptor->release();
-            }
-            
-            // Finally, deallocate our kernelDataBuffer
-            //
-            IOFree(kernelDataBuffer, sizeof(LowLatencyUserClientBufferInfo));
-            
-            kernelDataBuffer = nextBuffer;
-        }
-        
-        fUserClientBufferInfoListHead = NULL;
-    }
-}
-
 IOUSBLowLatencyCommand *
 IOUSBLowLatencyCommand::NewCommand()
 {
